@@ -87,6 +87,25 @@ typedef struct
 #endif
 } XfceDesktopMenu;
 
+
+/* silence some warnings... */
+G_MODULE_EXPORT XfceDesktopMenu *xfce_desktop_menu_new_impl(const gchar *menu_file,
+                                                            gboolean deferred);
+G_MODULE_EXPORT void xfce_desktop_menu_populate_menu_impl(XfceDesktopMenu *desktop_menu,
+                                                          GtkWidget *menu);
+G_MODULE_EXPORT GtkWidget *xfce_desktop_menu_get_widget_impl(XfceDesktopMenu *desktop_menu);
+G_MODULE_EXPORT G_CONST_RETURN gchar *xfce_desktop_menu_get_menu_file_impl(XfceDesktopMenu *desktop_menu);
+G_MODULE_EXPORT gboolean xfce_desktop_menu_need_update_impl(XfceDesktopMenu *desktop_menu);
+G_MODULE_EXPORT void xfce_desktop_menu_start_autoregen_impl(XfceDesktopMenu *desktop_menu,
+                                                            guint delay);
+G_MODULE_EXPORT void xfce_desktop_menu_stop_autoregen_impl(XfceDesktopMenu *desktop_menu);
+G_MODULE_EXPORT void xfce_desktop_menu_force_regen_impl(XfceDesktopMenu *desktop_menu);
+G_MODULE_EXPORT void xfce_desktop_menu_set_show_icons_impl(XfceDesktopMenu *desktop_menu,
+                                                           gboolean show_icons);
+G_MODULE_EXPORT void xfce_desktop_menu_destroy_impl(XfceDesktopMenu *desktop_menu);
+G_MODULE_EXPORT gchar *g_module_check_init(GModule *module);
+
+
 static void _xfce_desktop_menu_free_menudata(XfceDesktopMenu *desktop_menu);
 
 static gint _xfce_desktop_menu_icon_size = 24;
@@ -256,12 +275,12 @@ desktop_menu_add_items(XfceDesktopMenu *desktop_menu,
             gtk_widget_show(submenu);
             
             if(xfce_directory) {
-                name = xfce_menu_directory_get_name(xfce_directory);
                 if(desktop_menu->use_menu_icons)
                     icon_name = xfce_menu_directory_get_icon(xfce_directory);
-            } else
-                name = xfce_menu_get_name(xfce_submenu);
+            }
             
+            name = xfce_menu_element_get_name(XFCE_MENU_ELEMENT(xfce_submenu));
+
             mi = gtk_image_menu_item_new_with_label(name);
             if(icon_name) {
                 img = gtk_image_new_from_icon_name(icon_name,
@@ -295,8 +314,6 @@ desktop_menu_add_items(XfceDesktopMenu *desktop_menu,
             else
                 *menu_items_return = g_list_prepend(*menu_items_return, mi);
         } else if(XFCE_IS_MENU_ITEM(l->data)) {
-            const gchar *name = NULL;
-            
             xfce_item = l->data;
             
             if(xfce_menu_item_get_no_display(xfce_item)
@@ -305,12 +322,7 @@ desktop_menu_add_items(XfceDesktopMenu *desktop_menu,
                 continue;
             }
             
-            if(xfce_menu_item_has_category(xfce_item, "X-XFCE"))
-                name = xfce_menu_item_get_generic_name(xfce_item);
-            if(!name)
-                name = xfce_menu_item_get_name(xfce_item);
-            
-            mi = xfce_app_menu_item_new_full(name,
+            mi = xfce_app_menu_item_new_full(xfce_menu_element_get_name(XFCE_MENU_ELEMENT(xfce_item)),
                                              xfce_menu_item_get_command(xfce_item),
                                              desktop_menu->use_menu_icons
                                              ? xfce_menu_item_get_icon_name(xfce_item)
